package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TDeviceClock;
import com.ruoyi.system.service.ITDeviceClockService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备设置闹钟Controller
 * 
 * @author zhengjie
 * @date 2023-09-20
 */
@RestController
@RequestMapping("/system/deviceclock")
public class TDeviceClockController extends BaseController
{
    @Autowired
    private ITDeviceClockService tDeviceClockService;

    /**
     * 查询设备设置闹钟列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TDeviceClock tDeviceClock)
    {
        startPage();
        List<TDeviceClock> list = tDeviceClockService.selectTDeviceClockList(tDeviceClock);
        return getDataTable(list);
    }

    /**
     * 导出设备设置闹钟列表
     */
    @Log(title = "设备设置闹钟", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDeviceClock tDeviceClock)
    {
        List<TDeviceClock> list = tDeviceClockService.selectTDeviceClockList(tDeviceClock);
        ExcelUtil<TDeviceClock> util = new ExcelUtil<TDeviceClock>(TDeviceClock.class);
        util.exportExcel(response, list, "设备设置闹钟数据");
    }

    /**
     * 获取设备设置闹钟详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tDeviceClockService.selectTDeviceClockById(id));
    }

    /**
     * 新增设备设置闹钟
     */
    @Log(title = "设备设置闹钟", businessType = BusinessType.INSERT)
    @RequestMapping("/clockAdd")
    public AjaxResult add(@RequestBody List<TDeviceClock> tDeviceClock)
    {
        return toAjax(tDeviceClockService.insertTDeviceClock(tDeviceClock));
    }

    /**
     * 修改设备设置闹钟
     */
    @Log(title = "设备设置闹钟", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDeviceClock tDeviceClock)
    {
        return toAjax(tDeviceClockService.updateTDeviceClock(tDeviceClock));
    }

    /**
     * 删除设备设置闹钟
     */
    @Log(title = "设备设置闹钟", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tDeviceClockService.deleteTDeviceClockByIds(ids));
    }
}
