package com.ruoyi.web.controller.system;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.TreeSet;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.TFallSolve;
import com.ruoyi.system.domain.TOtherSolve;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TRailSolve;
import com.ruoyi.system.service.ITRailSolveService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 围栏告警处理Controller
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/railsolve")
public class TRailSolveController extends BaseController
{
    @Autowired
    private ITRailSolveService tRailSolveService;

    /**
     * 查询围栏告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:list')")
    @GetMapping("/list")
    public TableDataInfo list(TRailSolve tRailSolve)
    {
        startPage();
        List<TRailSolve> list = tRailSolveService.selectTRailSolveList(tRailSolve);
        for (TRailSolve salve : list){
            if (StringUtils.isNull(salve.getSolve_status())){
                salve.setSolve_status(0);
            }
            salve.setAlarmMsg("围栏告警求助：" + salve.getName() + "于" + DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,salve.getCreatetime()) + "发起围栏告警求助");
        }
        List<TRailSolve> collect=list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(()->new TreeSet<TRailSolve>(Comparator.comparing(TRailSolve::getAid))), ArrayList::new));
        return getDataTable(collect);
    }

    /**
     * 导出围栏告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:export')")
    @Log(title = "围栏告警处理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TRailSolve tRailSolve)
    {
        List<TRailSolve> list = tRailSolveService.selectTRailSolveList(tRailSolve);
        ExcelUtil<TRailSolve> util = new ExcelUtil<TRailSolve>(TRailSolve.class);
        util.exportExcel(response, list, "围栏告警处理数据");
    }

    /**
     * 获取围栏告警处理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tRailSolveService.selectTRailSolveById(id));
    }

    /**
     * 新增围栏告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:add')")
    @Log(title = "围栏告警处理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TRailSolve tRailSolve)
    {
        return toAjax(tRailSolveService.insertTRailSolve(tRailSolve));
    }

    /**
     * 修改围栏告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:edit')")
    @Log(title = "围栏告警处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TRailSolve tRailSolve)
    {
        return toAjax(tRailSolveService.updateTRailSolve(tRailSolve));
    }

    /**
     * 删除围栏告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:railsolve:remove')")
    @Log(title = "围栏告警处理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tRailSolveService.deleteTRailSolveByIds(ids));
    }
}
