package com.ruoyi.common.constant;

/**
 * 返回状态码
 *
 * @author ruoyi
 */
public class HttpStatus {
    /**
     * 操作成功
     */
    public static final int SUCCESS = 200;

    /**
     * 对象创建成功
     */
    public static final int CREATED = 201;

    /**
     * 请求已经被接受
     */
    public static final int ACCEPTED = 202;

    /**
     * 操作已经执行成功，但是没有返回数据
     */
    public static final int NO_CONTENT = 204;

    /**
     * 资源已被移除
     */
    public static final int MOVED_PERM = 301;

    /**
     * 重定向
     */
    public static final int SEE_OTHER = 303;

    /**
     * 资源没有被修改
     */
    public static final int NOT_MODIFIED = 304;

    /**
     * 参数列表错误（缺少，格式不匹配）
     */
    public static final int BAD_REQUEST = 400;

    /**
     * 未授权
     */
    public static final int UNAUTHORIZED = 401;

    /**
     * 访问受限，授权过期
     */
    public static final int FORBIDDEN = 403;

    /**
     * 资源，服务未找到
     */
    public static final int NOT_FOUND = 404;

    /**
     * 不允许的http方法
     */
    public static final int BAD_METHOD = 405;

    /**
     * 资源冲突，或者资源被锁
     */
    public static final int CONFLICT = 409;

    /**
     * 不支持的数据，媒体类型
     */
    public static final int UNSUPPORTED_TYPE = 415;

    /**
     * 系统内部错误
     */
    public static final int ERROR = 500;

    /**
     * 接口未实现
     */
    public static final int NOT_IMPLEMENTED = 501;

    /**
     * 系统警告消息
     */
    public static final int WARN = 601;

    //10000+ 为高德返回错误码

    /**
     * 高德-key不正确或过期
     * （开发者发起请求时，传入的key不正确或者过期 ）
     */
    public static final int AMAP_INVALID_USER_KEY = 10001;

    /**
     * 高德-没有权限使用相应的服务或者请求接口的路径拼写错误
     * （1.开发者没有权限使用相应的服务，例如：开发者申请了WEB定位功能的key，却使用该key访问逆地理编码功能时，就会返回该错误。反之亦然。
     * 2.开发者请求接口的路径拼写错误。例如：正确的https://restapi.amap.com/v3/ip在程序中被拼装写了https://restapi.amap.com/vv3/ip"）
     */
    public static final int AMAP_SERVICE_NOT_AVAILABLE = 10002;

    /**
     * 高德-访问已超出日访问量
     * （开发者的日访问量超限，被系统自动封停，第二天0:00会自动解封。）
     */
    public static final int AMAP_DAILY_QUERY_OVER_LIMIT = 10003;

    /**
     * 高德-单位时间内访问过于频繁
     * （开发者的单位时间内（1分钟）访问量超限，被系统自动封停，下一分钟自动解封。）
     */
    public static final int AMAP_ACCESS_TOO_FREQUENT = 10004;

    /**
     * 高德-IP白名单出错，发送请求的服务器IP不在IP白名单内
     * （开发者在LBS官网控制台设置的IP白名单不正确。白名单中未添加对应服务器的出口IP。可到"控制台>配置"  中设定IP白名单。）
     */
    public static final int AMAP_INVALID_USER_IP = 10005;

    /**
     * 高德-绑定域名无效
     * （开发者绑定的域名无效，需要在官网控制台重新设置）
     */
    public static final int AMAP_INVALID_USER_DOMAIN = 10006;

    /**
     * 高德-数字签名未通过验证
     * （开发者签名未通过开发者在key控制台中，开启了“数字签名”功能，但没有按照指定算法生成“数字签名”。）
     */
    public static final int AMAP_INVALID_USER_SIGNATURE = 10007;

    /**
     * 高德-MD5安全码未通过验证
     * （需要开发者判定key绑定的SHA1,package是否与sdk包里的一致）
     */
    public static final int AMAP_INVALID_USER_SCODE = 10008;

    /**
     * 高德-请求key与绑定平台不符
     * （请求中使用的key与绑定平台不符，例如：开发者申请的是js api的key，却用来调web服务接口）
     */
    public static final int AMAP_USERKEY_PLAT_NOMATCH = 10009;

    /**
     * 高德-IP访问超限
     * （未设定IP白名单的开发者使用key发起请求，从单个IP向服务器发送的请求次数超出限制，被系统自动封停。封停后无法自动恢复，需要提交工单联系我们。）
     */
    public static final int AMAP_IP_QUERY_OVER_LIMIT = 10010;

    /**
     * 高德-服务不支持https请求
     * （服务不支持https请求，如果需要申请支持，请提交工单联系我们）
     */
    public static final int AMAP_NOT_SUPPORT_HTTPS = 10011;

    /**
     * 高德-权限不足，服务请求被拒绝
     * （由于不具备请求该服务的权限，所以服务被拒绝。）
     */
    public static final int AMAP_INSUFFICIENT_PRIVILEGES = 10012;

    /**
     * 高德-Key被删除
     * （开发者删除了key，key被删除后无法正常使用）
     */
    public static final int AMAP_USER_KEY_RECYCLED = 10013;

    /**
     * 高德-云图服务QPS超限
     * （ QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_QPS_HAS_EXCEEDED_THE_LIMIT = 10014;

    /**
     * 高德-受单机QPS限流限制
     * （ 受单机QPS限流限制时出现该问题，建议降低请求的QPS或在控制台提工单联系我们）
     */
    public static final int AMAP_GATEWAY_TIMEOUT = 10015;

    /**
     * 高德-服务器负载过高
     * （服务器负载过高，请稍后再试）
     */
    public static final int AMAP_SERVER_IS_BUSY = 10016;

    /**
     * 高德-所请求的资源不可用
     * （所请求的资源不可用）
     */
    public static final int AMAP_RESOURCE_UNAVAILABLE = 10017;

    /**
     * 高德-使用的某个服务总QPS超限
     * （QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_CQPS_HAS_EXCEEDED_THE_LIMIT = 10019;

    /**
     * 高德-某个Key使用某个服务接口QPS超出限制
     * （QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_CKQPS_HAS_EXCEEDED_THE_LIMIT = 10020;

    /**
     * 高德-来自于同一IP的访问，使用某个服务QPS超出限制
     * （ QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_CIQPS_HAS_EXCEEDED_THE_LIMIT = 10021;

    /**
     * 高德-某个Key，来自于同一IP的访问，使用某个服务QPS超出限制
     * （QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_CIKQPS_HAS_EXCEEDED_THE_LIMIT = 10022;

    /**
     * 高德-某个KeyQPS超出限制
     * （QPS超出限制，超出部分的请求被拒绝。限流阈值内的请求依旧会正常返回）
     */
    public static final int AMAP_KQPS_HAS_EXCEEDED_THE_LIMIT = 10023;

    /**
     * 高德-权限不足
     * （数据的访问权限不足）
     */
    public static final int AMAP_INSUFFICIENT_PERMISSIONS = 10024;

    /**
     * 高德-请求参数非法
     * （ 请求参数的值没有按照规范要求填写。例如，某参数值域范围为[1,3],开发者误填了’4’）
     */
    public static final int AMAP_INVALID_PARAMS = 20000;

    /**
     * 高德-缺少必填参数
     * （缺少接口中要求的必填参数）
     */
    public static final int AMAP_MISSING_REQUIRED_PARAMS = 20001;

    /**
     * 高德-请求协议非法
     * （比如某接口仅支持get请求，结果用了POST方式）
     */
    public static final int AMAP_ILLEGAL_REQUEST = 20002;

    /**
     * 高德-其他未知错误
     * （其他未知错误，请通过工单反馈我们。）
     */
    public static final int AMAP_UNKNOWN_ERROR = 20003;

    /**
     * 高德-找不到ID
     * （找不到相应的ID）
     */
    public static final int AMAP_ID_NOT_FOUND = 20004;

    /**
     * 高德-数据流错误
     * （无法取得上传文件数据流）
     */
    public static final int AMAP_FILE_UPLOAD_FAILED = 20005;

    /**
     * 高德-协议错误
     * （协议错误）
     */
    public static final int AMAP_INVALID_BINARY_PROTOCOL = 20006;

    /**
     * 高德-解密失败
     * （解密失败）
     */
    public static final int AMAP_DECRYPTION_FAILED = 20007;

    /**
     * 高德-请求拒绝
     * （请求拒绝）
     */
    public static final int AMAP_REQUEST_BREAKER = 20008;

    /**
     * 高德-参数已存在
     * （填入的某些参数已经存在，请检查关键参数）
     */
    public static final int AMAP_EXISTING_ELEMENT = 20009;

    /**
     * 高德-参数不存在
     * （填入的查找参数不存在，请检查对应参数是否存在）
     */
    public static final int AMAP_UNEXISTING_ELEMENT = 20010;

    /**
     * 高德-服务不存在
     * （用户上传数据所绑定的服务不存在）
     */
    public static final int AMAP_SERVICE_NOT_FOUND = 20050;

    /**
     * 高德-设备不存在
     * （用户上传数据所绑定的设备不存在）
     */
    public static final int AMAP_TERMINAL_NOT_FOUND = 20051;

    /**
     * 高德-部分点上传失败
     * （部分点没有成功上传）
     */
    public static final int AMAP_PARTIAL_SUCCESS = 20100;

    /**
     * 高德-所有点上传失败
     * （所有点都上传失败）
     */
    public static final int AMAP_NOTHING_SUCCESS = 20101;

    /**
     * 高德-设备个数过多
     * （创建设备个数已超限）
     */
    public static final int AMAP_BEYOND_LIMIT = 20150;

    /**
     * 高德-服务响应失败
     * （出现3开头的错误码，请先按照接口文档检查传入参数是否正确，若无法解决，请详细描述错误复现信息，请通过工单反馈我们。
     * 如，30001、30002、30003、32000、32001、32002、32003、32200、32201、32202、32203。）
     */
    public static final int AMAP_ENGINE_RESPONSE_DATA_ERROR = 30000;

    /**
     * 高德-轨迹过长
     * （轨迹长度超过5000公里，请检查传入的原始轨迹是否合理；）
     */
    public static final int AMAP_TOO_LONG_TRACK = 32005;


}
