package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.system.domain.TDeviceList;
import com.ruoyi.system.domain.dto.*;

/**
 * 设备列Mapper接口
 *
 * @author zhengjie
 * @date 2023-08-30
 */
public interface TDeviceListMapper {
    /**
     * 查询设备列
     *
     * @param id 设备列主键
     * @return 设备列
     */
    public TDeviceList selectTDeviceListById(Integer id);

    /**
     * 查询设备列集合
     *
     * @param userId 用户ID
     * @return 设备列集合
     */
    public List<TDeviceList> selectTDeviceListByUserId(Integer userId);

    /**
     * 查询设备列列表
     *
     * @param tDeviceList 设备列
     * @return 设备列集合
     */
    public List<TDeviceList> selectTDeviceListList(TDeviceList tDeviceList);

    /**
     * 查询设备列列表
     *
     * @return 设备列集合
     */
    public List<TDeviceList> selectTDeviceList();

    /**
     * 查询设备列列表
     *
     * @return 设备列集合
     */
    public TDeviceList selectTDeviceListListByDeviceId(String device_id_code);

    /**
     * 查询心率列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByDeviceId(String device_id_code);

    /**
     * 查询血压列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByBlood(String device_id_code);

    /**
     * 查询血氧列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByOxygen(String device_id_code);

    /**
     * 查询体温列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByTemp(String device_id_code);

    /**
     * 查询步数列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByStep(String device_id_code);

    /**
     * 查询消息列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<MessageDto> selectTDeviceByMessage(String device_id_code);

    /**
     * 查询消息列表
     *
     * @param messageLogDto 设备id
     * @return 设备列集合
     */
    public List<MessageLogDto> selectTDeviceByMessageLog(MessageLogDto messageLogDto);

    /**
     * 修改最大心率
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_heart_max(String use_key);

    /**
     * 修改最小心率
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_heart_min(String use_key);

    /**
     * 修改高压最大
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_blood_high_max(String use_key);

    /**
     * 修改高压最小
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_blood_high_min(String use_key);

    /**
     * 修改低压最大
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_blood_low_max(String use_key);

    /**
     * 修改低压最小
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_blood_low_min(String use_key);

    /**
     * 修改血氧最大
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_oxygen_max(String use_key);

    /**
     * 修改血氧最小
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_oxygen_min(String use_key);

    /**
     * 修改体温最大
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_body_max(String use_key);

    /**
     * 修改体温最小
     *
     * @return 结果
     */
    public int updateTSettingshouhuan_body_min(String use_key);

    /**
     * 新增设备列
     *
     * @param tDeviceList 设备列
     * @return 结果
     */
    public int insertTDeviceList(TDeviceList tDeviceList);

    /**
     * 修改设备列
     *
     * @param tDeviceList 设备列
     * @return 结果
     */
    public int updateTDeviceList(TDeviceList tDeviceList);

    /**
     * 删除设备列
     *
     * @param id 设备列主键
     * @return 结果
     */
    public int deleteTDeviceListById(Integer id);

    /**
     * 批量删除设备列
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTDeviceListByIds(Integer[] ids);

    /**
     * 最大心率
     *
     * @return 结果
     */
    public String selectshouhuan(String use_key);

    /**
     * 最大心率
     *
     * @return 结果
     */
    public List<DeviceTypeDto> selectDeviceListDto();

    /**
     * 绑定设备
     *
     * @return 结果
     */
    public Integer selectDeviceListCount();

    /**
     * 查询设备绑定用户数
     *
     * @return 设备列集合
     */
    public Integer selectTDeviceListBandUser();

    /**
     * 设备新增
     *
     * @return 结果
     */
    public List<AddDeviceDto> selectAddDevice();
}
