package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TDeviceList;
import com.ruoyi.system.domain.TServiceManage;
import com.ruoyi.system.domain.dto.*;

/**
 * 设备列Service接口
 * 
 * @author zhengjie
 * @date 2023-08-30
 */
public interface ITDeviceListService 
{
    /**
     * 查询设备列
     * 
     * @param id 设备列主键
     * @return 设备列
     */
    public TDeviceList selectTDeviceListById(Integer id);

    /**
     * 查询设备列列表
     * 
     * @param tDeviceList 设备列
     * @return 设备列集合
     */
    public List<TDeviceList> selectTDeviceListList(TDeviceList tDeviceList);

    /**
     * 查询心率列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByDeviceId(String device_id_code);

    /**
     * 查询血压列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByBlood(String device_id_code);

    /**
     * 查询血氧列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByOxygen(String device_id_code);

    /**
     * 查询体温列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByTemp(String device_id_code);

    /**
     * 查询步数列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<RateDto> selectTDeviceByStep(String device_id_code);

    /**
     * 查询消息列表
     *
     * @param device_id_code 设备id
     * @return 设备列集合
     */
    public List<MessageDto> selectTDeviceByMessage(String device_id_code);

    /**
     * 查询消息列表
     *
     * @param messageLogDto 设备id
     * @return 设备列集合
     */
    public List<MessageLogDto> selectTDeviceByMessageLog(MessageLogDto messageLogDto);

    /**
     * 导入设备列表数据
     *
     * @param tDeviceLists 设备列表列表
     * @return 结果
     */
    public String importTDeviceList(List<TDeviceList> tDeviceLists);

    /**
     * 导入设备列表数据
     *
     * @param tDeviceLists 设备列表列表
     * @return 结果
     */
    public String importTDeviceListV2(List<TDeviceList> tDeviceLists);

    /**
     * 新增设备列
     * 
     * @param tDeviceList 设备列
     * @return 结果
     */
    public int insertTDeviceList(TDeviceList tDeviceList);

    /**
     * 修改设备列
     * 
     * @param tDeviceList 设备列
     * @return 结果
     */
    public int updateTDeviceList(TDeviceList tDeviceList);

    /**
     * 批量删除设备列
     * 
     * @param ids 需要删除的设备列主键集合
     * @return 结果
     */
    public int deleteTDeviceListByIds(Integer[] ids);

    /**
     * 删除设备列信息
     * 
     * @param id 设备列主键
     * @return 结果
     */
    public int deleteTDeviceListById(Integer id);

    /**
     * 判断报警信息
     *
     * @param alarm_type 报警类型
     * @return 结果
     */
    public String checkMessage(Integer alarm_type);

    /**
     * 修改设备阈值
     *
     * @param callPoliceDto 设备列
     * @return 结果
     */
    public int deviceValue(CallPoliceDto callPoliceDto);

    /**
     * 最大心率
     *
     * @return 结果
     */
    public List<DeviceTypeDto> selectDeviceListDto();

    /**
     * 最大心率
     *
     * @return 结果
     */
    public Integer selectDeviceListCount();

    /**
     * 设备新增
     *
     * @return 结果
     */
    public List<AddDeviceDto> selectAddDevice();

    /**
     * 查询设备绑定用户数
     *
     * @return 设备列集合
     */
    public Integer selectTDeviceListBandUser();
}
