package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.TServiceManage;
import com.ruoyi.system.domain.TUserProfile;
import com.ruoyi.system.domain.dto.AddUserDto;
import com.ruoyi.system.domain.dto.TUserProfileDto;
import com.ruoyi.system.domain.dto.UserAgeDto;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户档案Service接口
 *
 * @author zhengjie
 * @date 2023-08-25
 */
public interface ITUserProfileService {
    /**
     * 查询用户档案
     *
     * @param id 用户档案主键
     * @return 用户档案
     */
    public TUserProfile selectTUserProfileById(Integer id);

    /**
     * 查询用户档案列表
     *
     * @param tUserProfile 用户档案
     * @return 用户档案集合
     */
    public List<TUserProfile> selectTUserProfileList(TUserProfile tUserProfile);


    /**
     * 查询用户档案列表
     *
     * @param tUserProfileDto 用户档案
     * @return 用户档案集合
     */
    public List<TUserProfileDto> selectTUserProfileListByDevice(TUserProfileDto tUserProfileDto);

    /**
     * 新增用户档案
     *
     * @param tUserProfile 用户档案
     * @return 结果
     */
    public int insertTUserProfile(TUserProfile tUserProfile);

    /**
     * 修改用户档案
     *
     * @param tUserProfile 用户档案
     * @return 结果
     */
    public int updateTUserProfile(TUserProfile tUserProfile);

    /**
     * 批量删除用户档案
     *
     * @param ids 需要删除的用户档案主键集合
     * @return 结果
     */
    public int deleteTUserProfileByIds(Integer[] ids);

    /**
     * 删除用户档案信息
     *
     * @param id 用户档案主键
     * @return 结果
     */
    public int deleteTUserProfileById(Integer id);

    /**
     * 导入用户档案数据
     *
     * @param tUserProfileList 用户档案列表
     * @return 结果
     */
    public String importTUserProfile(List<TUserProfile> tUserProfileList);

    /**
     * 导入用户档案数据
     *
     * @param tUserProfileList 用户档案列表
     * @return 结果
     */
    public String importTUserProfileV2(List<TUserProfile> tUserProfileList);

    /**
     * 用户年龄
     *
     * @return 结果
     */
    public List<UserAgeDto> selectuserAgeDto();

    /**
     * 用户总数
     *
     * @return 结果
     */
    public Integer selectuserAgeCount();

    /**
     * 用户新增
     *
     * @return 结果
     */
    public List<AddUserDto> selectAddUser();
}
