package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TDeviceClockMapper;
import com.ruoyi.system.domain.TDeviceClock;
import com.ruoyi.system.service.ITDeviceClockService;

/**
 * 设备设置闹钟Service业务层处理
 * 
 * @author zhengjie
 * @date 2023-09-20
 */
@Service
public class TDeviceClockServiceImpl implements ITDeviceClockService 
{
    @Autowired
    private TDeviceClockMapper tDeviceClockMapper;

    /**
     * 查询设备设置闹钟
     * 
     * @param id 设备设置闹钟主键
     * @return 设备设置闹钟
     */
    @Override
    public TDeviceClock selectTDeviceClockById(Integer id)
    {
        return tDeviceClockMapper.selectTDeviceClockById(id);
    }

    /**
     * 查询设备设置闹钟
     *
     * @param deviceIdCode 设备设置号
     * @return 设备设置闹钟
     */
    @Override
    public TDeviceClock selectTDeviceClockByCode(String deviceIdCode) {
        return tDeviceClockMapper.selectTDeviceClockByCode(deviceIdCode);
    }

    /**
     * 查询设备设置闹钟列表
     * 
     * @param tDeviceClock 设备设置闹钟
     * @return 设备设置闹钟
     */
    @Override
    public List<TDeviceClock> selectTDeviceClockList(TDeviceClock tDeviceClock)
    {
        return tDeviceClockMapper.selectTDeviceClockList(tDeviceClock);
    }

    /**
     * 新增设备设置闹钟
     * 
     * @param tDeviceClock 设备设置闹钟
     * @return 结果
     */
    @Override
    public int insertTDeviceClock(List<TDeviceClock> tDeviceClock)
    {
        if (StringUtils.isNotNull(tDeviceClock)) {
            for (TDeviceClock clock : tDeviceClock) {
                tDeviceClockMapper.insertTDeviceClock(clock);
            }
        }
        return 1;
    }

    /**
     * 修改设备设置闹钟
     * 
     * @param tDeviceClock 设备设置闹钟
     * @return 结果
     */
    @Override
    public int updateTDeviceClock(TDeviceClock tDeviceClock)
    {
        return tDeviceClockMapper.updateTDeviceClock(tDeviceClock);
    }

    /**
     * 批量删除设备设置闹钟
     * 
     * @param ids 需要删除的设备设置闹钟主键
     * @return 结果
     */
    @Override
    public int deleteTDeviceClockByIds(Integer[] ids)
    {
        return tDeviceClockMapper.deleteTDeviceClockByIds(ids);
    }

    /**
     * 删除设备设置闹钟信息
     * 
     * @param id 设备设置闹钟主键
     * @return 结果
     */
    @Override
    public int deleteTDeviceClockById(Integer id)
    {
        return tDeviceClockMapper.deleteTDeviceClockById(id);
    }
}
