package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TRegionVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TRegionMapper;
import com.ruoyi.system.domain.TRegion;
import com.ruoyi.system.service.ITRegionService;

/**
 * 行政区域Service业务层处理
 *
 * @author zhengjie
 * @date 2023-08-15
 */
@Service
public class TRegionServiceImpl implements ITRegionService {
    @Autowired
    private TRegionMapper tRegionMapper;

    /**
     * 查询行政区域
     *
     * @param id 行政区域主键
     * @return 行政区域
     */
    @Override
    public TRegion selectTRegionById(Integer id) {
        return tRegionMapper.selectTRegionById(id);
    }

    /**
     * 查询行政区域列表
     *
     * @param tRegion 行政区域
     * @return 行政区域
     */
    @Override
    public List<TRegion> selectTRegionList(TRegion tRegion) {
        return tRegionMapper.selectTRegionList(tRegion);
    }

    @Override
    public List<TRegion> selectTRegionListV2(TRegion tRegion) {
        List<TRegionVo> list_1 = tRegionMapper.selectTRegionListV1();
        for (TRegionVo vo_1 : list_1) {
            List<TRegionVo> list_2 = tRegionMapper.selectTRegionListV2(vo_1.getCode());
            for (TRegionVo vo_2 : list_2) {
                List<TRegionVo> list_3 = tRegionMapper.selectTRegionListV3(vo_2.getCode());
                for (TRegionVo vo_3 : list_3) {
                    List<TRegionVo> list_4 = tRegionMapper.selectTRegionListV4(vo_3.getCode());
                    for (TRegionVo vo_4 : list_4) {
                        List<TRegionVo> list_5 = tRegionMapper.selectTRegionListV5(vo_4.getCode());
                        vo_4.setChild(list_5);
                    }
                    vo_3.setChild(list_4);
                }
                vo_2.setChild(list_3);
            }
            vo_1.setChild(list_2);
        }
        return tRegionMapper.selectTRegionList(tRegion);
    }

    /**
     * 新增行政区域
     *
     * @param tRegion 行政区域
     * @return 结果
     */
    @Override
    public int insertTRegion(TRegion tRegion) {
        if (tRegion.getParentId() == 0) {
            TRegion t = tRegionMapper.selectTRegionById(1);
            tRegion.setCreateTime(DateUtils.getNowDate());
            tRegion.setParentId(1);
            tRegion.setAncestors("0,1");
            return tRegionMapper.insertTRegion(tRegion);
        } else {
            TRegion t = tRegionMapper.selectTRegionById(tRegion.getParentId());
            tRegion.setCreateTime(DateUtils.getNowDate());
            tRegion.setAncestors(t.getAncestors() + "," + tRegion.getParentId());
            return tRegionMapper.insertTRegion(tRegion);
        }
    }

    /**
     * 修改行政区域
     *
     * @param tRegion 行政区域
     * @return 结果
     */
    @Override
    public int updateTRegion(TRegion tRegion) {
        tRegion.setUpdateTime(DateUtils.getNowDate());
        return tRegionMapper.updateTRegion(tRegion);
    }

    /**
     * 批量删除行政区域
     *
     * @param ids 需要删除的行政区域主键
     * @return 结果
     */
    @Override
    public int deleteTRegionByIds(Integer[] ids) {
        return tRegionMapper.deleteTRegionByIds(ids);
    }

    /**
     * 删除行政区域信息
     *
     * @param id 行政区域主键
     * @return 结果
     */
    @Override
    public int deleteTRegionById(Integer id) {
        return tRegionMapper.deleteTRegionById(id);
    }
}
